pub enum AddressSpace {
Function,
Private,
WorkGroup,
Uniform,
Storage {
access: StorageAccess,
},
Handle,
Immediate,
TaskPayload,
RayPayload,
IncomingRayPayload,
}Expand description
Addressing space of variables.
Variants
Function
Function locals.
Private
Private data, per invocation, mutable.
WorkGroup
Workgroup shared data, mutable.
Uniform
Uniform buffer data.
Storage
Storage buffer data, potentially mutable.
Fields
access: StorageAccessHandle
Opaque handles, such as samplers and images.
Immediate
Immediate data.
A Module may contain at most one GlobalVariable in
this address space. Its contents are provided not by a buffer
but by SetImmediates pass commands, allowing the CPU to
establish different values for each draw/dispatch.
Immediate variables may not contain f16 values, even if
the SHADER_FLOAT16 capability is enabled.
Backends generally place tight limits on the size of
Immediate variables.
TaskPayload
Task shader to mesh shader payload
RayPayload
Ray tracing payload, for inputting in TraceRays
IncomingRayPayload
Ray tracing payload, for entrypoints invoked by a TraceRays call
Each entrypoint may reference only one variable in this scope, as only one may be passed as a payload.
Implementations
Sourceimpl AddressSpace
impl AddressSpace
pub fn access(self) -> StorageAccess
Sourceimpl AddressSpace
impl AddressSpace
pub const fn is_workgroup_like(self) -> bool